@@ -255,7 +255,17 @@ class FormMixin(LayoutHelperMixin, j01.jsonrpc.HistoryStateMixin):
         pass
 
     def applyWidgetFactories(self):
-        """Apply widget factories"""
+        """Apply widget factories
+
+        HEADSUP: if you switch modes based on application logic, you must
+        setup the fields as self.fields in setUpWidgetFields. This is because
+        the fields manager is a class instance and this switch is global for
+        all form instances.
+
+        NOTE: self.fields = self.fields.copy() does not work because it's
+        broken. It will copy the field instances located inside the Fields
+        instance as is.
+        """
         for name, factory in self.widgetFactories.items():
             try:
                 self.fields[name].widgetFactory = factory
@@ -263,7 +273,17 @@ class FormMixin(LayoutHelperMixin, j01.jsonrpc.HistoryStateMixin):
                 pass
 
     def applyWidgetModes(self):
-        """Apply widget mode"""
+        """Apply widget mode
+
+        HEADSUP: if you switch modes based on application logic, you must
+        setup the fields as self.fields in setUpWidgetFields. This is because
+        the fields manager is a class instance and this switch is global for
+        all form instances.
+
+        NOTE: self.fields = self.fields.copy() does not work because it's
+        broken. It will copy the field instances located inside the Fields
+        instance as is.
+        """
         for name, mode in self.widgetModes.items():
             try:
                 self.fields[name].mode = mode
@@ -271,7 +291,17 @@ class FormMixin(LayoutHelperMixin, j01.jsonrpc.HistoryStateMixin):
                 pass
 
     def applyIgnoreContext(self):
-        """Apply ignore context marker"""
+        """Apply ignore context marker
+
+        HEADSUP: if you switch modes based on application logic, you must
+        setup the fields as self.fields in setUpWidgetFields. This is because
+        the fields manager is a class instance and this switch is global for
+        all form instances.
+
+        NOTE: self.fields = self.fields.copy() does not work because it's
+        broken. It will copy the field instances located inside the Fields
+        instance as is.
+        """
         for name, state in self.widgetIgnoreContexts.items():
             try:
                 self.fields[name].ignoreContext = state
